==> blue2-theme-neilson-recruitment-1.0.16-461b77.tar: templates/parts/site-header.php <==
<nav class="<?php if (is_front_page()) : echo "front-page-header" ; else: echo "secondary-header"; endif;?>" <?php if (is_front_page()) : ?> style="background-image: url('<?=get_field('navigation_background_image'); ?>');" <?php endif;?> >
    <div class="container-fluid mobile-nav-contact-details-container">
        <div class="row">
            <div class="col-6">
                <div class="contact-btns">
                    <a href="<?= site_url(); ?>/contact-us"><i class="fas fa-phone-alt"></i></a>
                    <a href="<?= site_url(); ?>/contact-us"><i class="far fa-envelope"></i></a>
                </div>
            </div>
            <div class="col-6">
                <div class="upload-cv-btn">
                    <a href="<?= site_url(); ?>/contact-us">Upload CV</a>
                </div>
            </div>
        </div>
    </div>
    <div class="header-contents container-fluid site-padding">
        <div class="row justify-content-between">
            <div class="col-8 col-md-8 col-lg-4 show-above-dropdown">
                <a class="navbar-brand" href="<?php echo esc_url(home_url('/')); ?>">
                    <img src="<?= get_field('header_logo', 'options'); ?>" alt="<?php bloginfo('name'); ?>" />
                </a>
            </div>
            <div class="col-4 col-md-4 col-lg-8 mobile-align-hamburger">
                <div class="row">
                    <div class="d-none d-lg-block col-lg-12 show-above-dropdown">
                        <ul class="nav-contact-details">
                            <li><i class="fas fa-phone-alt"></i> 0131 338 6145</li>
                            <li><a href="<?= site_url(); ?>/contact-us"><i class="far fa-envelope"></i>EMAIL US</a></li>
                            <li><a href="<?= site_url(); ?>/contact-us">Upload CV | Login</a></li>
                        </ul>
                    </div>
                    <div class="d-sm-none d-lg-block col-lg-10 show-above-dropdown">
                        <div class="desktop-main-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'desktop-main-menu' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="col-12 col-lg-2 hamburger-menu" id="hamburger-menu">
                        <i class="fas fa-bars"></i>
                    </div>
                </div>
                
            </div>
        </div>
    </div>
    <div class="container-fluid site-padding" style="display: block;">
        <div class="row">
            <div class="col show-above-dropdown">
                <hr class="navigation-hr">
            </div>
        </div>
    </div>
    <?php if (is_front_page()) : ?>
        <div class="container-fluid site-padding" style="display: block;">
            <div class="row">
                <div class="col-lg-6">
                    <h1 class="header-text"><?=get_field("header_text");?></h1>
                    <?php if (get_field('header_job_search_from_shortcode') != '') : ?>
                        <form role="search" method="get" action="<?php echo site_url(); ?>/jobs" class="header-search-form">
                            <div class="form-group">
                                <input type="text" class="form-control" name="keyword" placeholder="Job title, Keyword">
                                <input type="text" class="form-control" name="location" placeholder="City, town, postal code">
                                <button type="submit" class="btn btn-primary form-control">Search Jobs →</button>
                            </div>
                        </form>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    <?php endif; ?>
</nav>
<div class="dropdown-nav" id="dropdown-nav">
    <div class="container-fluid site-padding">
        <div class="row">
            <div class="col-lg-6">
                <img src="<?= get_field('header_navigation_dropdown_image', 'options'); ?>" alt="">
            </div>
            <div class="col-lg-6">
                <div class="row">
                    <div class="col-lg-3 col-md-6">
                        <div class="dropdown-menu-items dropdown-left-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-left' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6">
                        <div class="dropdown-menu-items dropdown-right-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-right' 
                                )); 
                            ?>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <div class="header-navbar-socials">
                            <hr/>
                            <ul class="social-media-list">
                                <li>Follow Us </li>
                                <?php while( have_rows('social_media_channels', 'options') ) : the_row(); ?>
                                    <a href="<?=get_sub_field('full_url');?>" target="_blank"><li><i class="<?= get_sub_field('fa5_icon_class'); ?>"></i></li></a>
                                <?php endwhile; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col show-above-dropdown">
                <hr class="navigation-hr">
            </div>
        </div>
    </div>
</div>
<div class="dropdown-nav-overlay hide" id="dropdown-nav-overlay"></div>

==> blue2-theme-neilson-recruitment-1.0.28-52661a.tar: templates/parts/site-header.php <==
<nav class="<?php if (is_front_page()) : echo "front-page-header" ; else: echo "secondary-header"; endif;?>" <?php if (is_front_page()) : ?> style="background-image: url('<?=get_field('navigation_background_image'); ?>');" <?php endif;?> >
    <div class="container-fluid mobile-nav-contact-details-container">
        <div class="row">
            <div class="col-6">
                <div class="contact-btns">
                    <a href="tel:<?= get_field('contact_phone_number', 'options'); ?>"><i class="fas fa-phone-alt"></i></a>
                    <a href="mailto:<?= get_field('contact_email_address', 'options'); ?>"><i class="far fa-envelope"></i></a>
                </div>
            </div>
            <div class="col-6">
                <div class="upload-cv-btn">
                    <a href="<?= site_url(); ?>/contact-us">Upload CV</a>
                </div>
            </div>
        </div>
    </div>
    <div class="header-contents container-fluid site-padding">
        <div class="row justify-content-between">
            <div class="col-8 col-md-8 col-lg-4 show-above-dropdown">
                <a class="navbar-brand" href="<?php echo esc_url(home_url('/')); ?>">
                    <img src="<?= get_field('header_logo', 'options'); ?>" alt="<?php bloginfo('name'); ?>" />
                </a>
            </div>
            <div class="col-4 col-md-4 col-lg-8 mobile-align-hamburger">
                <div class="row">
                    <div class="d-none d-lg-block col-lg-12 show-above-dropdown">
                        <ul class="nav-contact-details">
                            <li style="margin-top:5px;"><a href="tel:<?= get_field('contact_phone_number', 'options'); ?>"><i class="fas fa-phone-alt"></i> <?= get_field('contact_phone_number', 'options'); ?></li></a>
                            <li style="margin-top:5px;"><a href="mailto:<?= get_field('contact_email_address', 'options'); ?>"><i class="far fa-envelope"></i>EMAIL US</a></li>
                            <li><a href="<?= site_url(); ?>/contact-us">Upload CV</a></li>
                        </ul>
                    </div>
                    <div class="d-sm-none d-lg-block col-lg-10 show-above-dropdown">
                        <div class="desktop-main-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'desktop-main-menu' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="col-12 col-lg-2 hamburger-menu" id="hamburger-menu">
                        <i class="fas fa-bars"></i>
                    </div>
                </div>
                
            </div>
        </div>
    </div>
    <div class="container-fluid site-padding" style="display: block;">
        <div class="row">
            <div class="col show-above-dropdown">
                <hr class="navigation-hr">
            </div>
        </div>
    </div>
    <?php if (is_front_page()) : ?>
        <div class="container-fluid site-padding" style="display: block;">
            <div class="row">
                <div class="col-lg-6">
                    <h1 class="header-text"><?=get_field("header_text");?></h1>
                    <?php if (get_field('header_job_search_from_shortcode') != '') : ?>
                        <form role="search" method="get" action="<?php echo site_url(); ?>/jobs" class="header-search-form">
                            <div class="form-group">
                                <input type="text" class="form-control" name="keyword" placeholder="Job title, Keyword">
                                <input type="text" class="form-control" name="location" placeholder="City, town, postal code">
                                <button type="submit" class="btn btn-primary form-control">Search Jobs →</button>
                            </div>
                        </form>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    <?php endif; ?>
</nav>
<div class="dropdown-nav" id="dropdown-nav">
    <div class="container-fluid site-padding">
        <div class="row">
            <div class="col-lg-6">
                <img src="<?= get_field('header_navigation_dropdown_image', 'options'); ?>" alt="">
            </div>
            <div class="col-lg-6">
                <div class="row">
                    <div class="d-sm-block d-md-none col-md-12">
                        <div class="dropdown-menu-items dropdown-left-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'mobile-full-menu' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="d-none d-md-block col-lg-3 col-md-6">
                        <div class="dropdown-menu-items dropdown-left-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-left' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="d-none d-md-block col-lg-3 col-md-6">
                        <div class="dropdown-menu-items dropdown-right-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-right' 
                                )); 
                            ?>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <div class="header-navbar-socials">
                            <hr/>
                            <ul class="social-media-list">
                                <li>Follow Us </li>
                                <?php while( have_rows('social_media_channels', 'options') ) : the_row(); ?>
                                    <a href="<?=get_sub_field('full_url');?>" target="_blank"><li><i class="<?= get_sub_field('fa5_icon_class'); ?>"></i></li></a>
                                <?php endwhile; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col show-above-dropdown">
                <hr class="navigation-hr">
            </div>
        </div>
    </div>
</div>
<div class="dropdown-nav-overlay hide" id="dropdown-nav-overlay"></div>
